---
title: Resource Records
permalink: /docs/records/types/resource/
toc:
  title: Resource
  expand: Records
jumbotron:
  title: Resource
  tagline: 
  breadcrumbs:
  -
    label: Docs &raquo;
    url: /docs/home/
  -
    label: Records &raquo;
    url: /docs/records/
  -
    label: Types &raquo;
    url: /docs/records/types/
---

|---
|-|-
| **Name (singular):** | Resource
| **Name (plural):** | Resources
| **Alias (uri):** | resource
| **Identifier (ID):** | cerb.contexts.resource

* TOC
{:toc}

### Records API

These fields are available in the [Records API](/docs/api/endpoints/records/) and [packages](/docs/packages/):

|---
| Req'd | Field | Type | Notes
|:-:|-|-|-
|   | `automation_kata` | [text](/docs/records/fields/types/text/) |  
|   | `cache_until` | [timestamp](/docs/records/fields/types/timestamp/) |  
|   | `content` | [text](/docs/records/fields/types/text/) | The optional content of this resource. For text, use a string. For binary, base64-encode in [data URI format](https://en.wikipedia.org/wiki/Data_URI_scheme). This may also be an automation resource URI (e.g. `cerb:automation_resource:TOKEN`) 
|   | `description` | [text](/docs/records/fields/types/text/) |  
| **x** | **`extension_id`** | [text](/docs/records/fields/types/text/) | A [cerb.resource.type](/docs/plugins/extensions/points/cerb.resource.type/#extensions) extension ID. 
|   | `is_dynamic` | [boolean](/docs/records/fields/types/boolean/) |  
|   | `links` | [links](/docs/records/fields/types/links/) | An array of record `type:id` tuples to link to. Prefix with `-` to unlink. 
| **x** | **`name`** | [text](/docs/records/fields/types/text/) | The name of this resource 
|   | `updated_at` | [timestamp](/docs/records/fields/types/timestamp/) | The date/time when this record was last modified 

### Dictionary Placeholders

These [placeholders](/docs/scripting/variables/#placeholders) are available in [dictionaries](/docs/guide/developers/dictionaries/) for [automations](/docs/automations/), [snippets](/docs/snippets/), and [API](/docs/api/) responses:

|---
| Field | Type | Description
|-|-|-
| `_context` | text | [Record type](/docs/records/types/) extension ID
| `_label` | text | Label
| `_type` | text | [Record type](/docs/records/types/) alias
| `automation_kata` | text | Automation
| `cache_until` | date | Cache Until
| `description` | text | Description
| `extension_id` | text | Type
| `id` | number | Id
| `is_dynamic` | boolean | Is Dynamic
| `name` | text | Name
| `record_url` | text | Record Url
| `updated_at` | date | Updated

These optional placeholders are also available with **key expansion** in [dictionaries](/docs/guide/developers/dictionaries/#key-expansion) and the [API](/docs/api/responses/#expanding-keys-in-api-requests):

|---
| Field | Type | Description
|-|-|-
| `comment_count` | number | [Comment](/docs/records/types/comments/) count on the record
| `comments` | comments | [Comments](/docs/guide/developers/dictionaries/#key-expansion)
| `custom_<id>` | mixed | [Custom Fields](/docs/guide/developers/dictionaries/#key-expansion)
| `links` | links | [Links](/docs/guide/developers/dictionaries/#key-expansion)
	
### Search Query Fields

These [filters](/docs/search/#filters) are available in resource [search queries](/docs/search/):

|---
| Field | Type | Description
|-|-|-
| `cacheUntil:` | [date](/docs/search/#dates) | Cache
| `description:` | [text](/docs/search/#text) | Description
| `fieldset:` | [record](/docs/search/#deep-search) | [Fieldset](/docs/records/types/custom_fieldset/)
| `id:` | [number](/docs/search/#numbers) | Id
| `isDynamic:` | [boolean](/docs/search/#booleans) | Is Dynamic
| `links:` | [links](/docs/search/#links) | Record Links
| `name:` | [text](/docs/search/#text) | Name
| `size:` | [number](/docs/search/#numbers) | Size
| `type:` | [text](/docs/search/#text) | Type
| `updated:` | [date](/docs/search/#dates) | Updated
	
### Worklist Columns

These columns are available on resource [worklists](/docs/worklists/):

|---
| Column | Description
|-|-
| `cf_<id>` | [Custom Field](/docs/records/types/custom_field/)
| `r_cache_until` | Cache
| `r_description` | Description
| `r_extension_id` | Type
| `r_id` | Id
| `r_is_dynamic` | Is Dynamic
| `r_name` | Name
| `r_storage_extension` | Storage Extension
| `r_storage_key` | Storage Key
| `r_storage_profile_id` | Storage Profile
| `r_storage_size` | Size
| `r_updated_at` | Updated

<div class="section-nav">
	<div class="left">
		<a href="/docs/records/types/" class="prev">&lt; Record Types</a>
	</div>
	<div class="right align-right">
	</div>
</div>
<div class="clear"></div>